@@ -271,6 +271,11 @@ register_rpc_service ()
                                      "seafile_get_sync_notification",
                                      searpc_signature_json__void());
 
+    searpc_server_register_function ("seafile-rpcserver",
+                                     seafile_shutdown,
+                                     "seafile_shutdown",
+                                     searpc_signature_int__void());
+
     /* Need to run in a thread since diff may take long. */
     searpc_server_register_function ("seafile-threaded-rpcserver",
                                      seafile_diff,
